==> ngx-weui-7.1.0-rc.2.tgz: package/README.md <==

<h1 align="center">
ngx-weui
</h1>

<div align="center">

[WeUI](https://github.com/weui/weui) Components build with [Angular](https://angular.io/).

[![Build Status](https://img.shields.io/travis/cipchk/ngx-weui/master.svg?style=flat-square)](https://travis-ci.org/cipchk/ngx-weui)
[![NPM version](https://img.shields.io/npm/v/ngx-weui.svg?style=flat-square)](https://www.npmjs.com/package/ngx-weui)
[![npm downloads](https://img.shields.io/npm/dm/ngx-weui.svg?style=flat-square)](https://npmjs.org/ngx-weui)
[![Codecov](https://img.shields.io/codecov/c/github/cipchk/ngx-weui.svg?style=flat-square)](https://codecov.io/gh/cipchk/ngx-weui)
[![GitHub license](https://img.shields.io/github/license/mashape/apistatus.svg?style=flat-square)](https://github.com/cipchk/ngx-weui/blob/master/LICENSE)
[![prettier](https://img.shields.io/badge/code_style-prettier-ff69b4.svg?style=flat-square)](https://prettier.io/)

</div>

[![](https://cdn-images-1.medium.com/max/1600/1*ceWDQUy3-MQgEchW6SuSRA.png)](https://cipchk.github.io/ngx-weui/)

## Version

- WeUI 1.x using `7.0.x`
- WeUI 2.x using `7.1.0-rc.x` (in next version)

## Table of Contents

1. [Usage & Demo](#usage--demo)
2. [Installation instructions](#installation-instructions)
3. [API Docs](https://cipchk.github.io/ngx-weui/)
4. [Customize Theme](https://cipchk.github.io/ngx-weui/#/docs/style)
5. [Global Config](https://cipchk.github.io/ngx-weui/#/docs/config)
6. [Troubleshooting](#troubleshooting)
7. [License](#license)

## Usage & Demo

- [Documentation](https://cipchk.github.io/ngx-weui/)
- [Live Demo](https://cipchk.github.io/ngx-weui/)
- [Stackblitz](https://stackblitz.com/edit/ngx-weui)

## Create project

1. Install global `angular-cli`:

```bash
npm install -g @angular/cli
```

2. New a empty angular project

```bash
# Specify less style
ng new demo --style less
cd demo
```

3. add `ngx-weui`

```bash
ng add ngx-weui@next
# Using WeUI 1.x
# ng add ngx-weui
```

> please refer to more [details](https://github.com/cipchk/ngx-weui/blob/master/docs/how.md).

### How to use it with:

+ `angular-cli` please refer to [how](https://github.com/cipchk/ngx-weui/blob/master/docs/how.md).
+ `stackblitz` sample available [here](https://stackblitz.com/edit/ngx-weui).

## Troubleshooting

Please follow this guidelines when reporting bugs and feature requests:

1. Use [GitHub Issues](https://github.com/cipchk/ngx-weui/issues) board to report bugs and feature requests (not our email address)
2. Please **always** write steps to reproduce the error. That way we can focus on fixing the bug, not scratching our heads trying to reproduce it.

Thanks for understanding!

### License

The MIT License (see the [LICENSE](https://github.com/cipchk/ngx-weui/blob/master/LICENSE) file for the full text)

==> ngx-weui-8.0.0.tgz: package/README.md <==

<h1 align="center">
ngx-weui
</h1>

<div align="center">

[WeUI](https://github.com/weui/weui) Components build with [Angular](https://angular.io/).

[![Build Status](https://img.shields.io/travis/cipchk/ngx-weui/master.svg?style=flat-square)](https://travis-ci.org/cipchk/ngx-weui)
[![NPM version](https://img.shields.io/npm/v/ngx-weui.svg?style=flat-square)](https://www.npmjs.com/package/ngx-weui)
[![npm downloads](https://img.shields.io/npm/dm/ngx-weui.svg?style=flat-square)](https://npmjs.org/ngx-weui)
[![Codecov](https://img.shields.io/codecov/c/github/cipchk/ngx-weui.svg?style=flat-square)](https://codecov.io/gh/cipchk/ngx-weui)
[![GitHub license](https://img.shields.io/github/license/mashape/apistatus.svg?style=flat-square)](https://github.com/cipchk/ngx-weui/blob/master/LICENSE)
[![prettier](https://img.shields.io/badge/code_style-prettier-ff69b4.svg?style=flat-square)](https://prettier.io/)

</div>

[![](https://cdn-images-1.medium.com/max/1600/1*ceWDQUy3-MQgEchW6SuSRA.png)](https://cipchk.github.io/ngx-weui/)

## Version

- WeUI 1.x using `7.0.x`
- WeUI 2.x using `7.1.x` (in next version)

## Table of Contents

1. [Usage & Demo](#usage--demo)
2. [Installation instructions](#installation-instructions)
3. [API Docs](https://cipchk.github.io/ngx-weui/)
4. [Customize Theme](https://cipchk.github.io/ngx-weui/#/docs/style)
5. [Global Config](https://cipchk.github.io/ngx-weui/#/docs/config)
6. [Troubleshooting](#troubleshooting)
7. [License](#license)

## Usage & Demo

- [Documentation](https://cipchk.github.io/ngx-weui/)
- [Live Demo](https://cipchk.github.io/ngx-weui/)
- [Stackblitz](https://stackblitz.com/edit/ngx-weui)

## Create project

1. Install global `angular-cli`:

```bash
npm install -g @angular/cli
```

2. New a empty angular project

```bash
# Specify less style
ng new demo --style less
cd demo
```

3. add `ngx-weui`

```bash
ng add ngx-weui@next
# Using WeUI 1.x
# ng add ngx-weui
```

> please refer to more [details](https://github.com/cipchk/ngx-weui/blob/master/docs/how.md).

### How to use it with:

+ `angular-cli` please refer to [how](https://github.com/cipchk/ngx-weui/blob/master/docs/how.md).
+ `stackblitz` sample available [here](https://stackblitz.com/edit/ngx-weui).

## Troubleshooting

Please follow this guidelines when reporting bugs and feature requests:

1. Use [GitHub Issues](https://github.com/cipchk/ngx-weui/issues) board to report bugs and feature requests (not our email address)
2. Please **always** write steps to reproduce the error. That way we can focus on fixing the bug, not scratching our heads trying to reproduce it.

Thanks for understanding!

### License

The MIT License (see the [LICENSE](https://github.com/cipchk/ngx-weui/blob/master/LICENSE) file for the full text)
